Welcome to Sanskrit Sandhi's documentation!
===========================================


.. image:: https://img.shields.io/pypi/v/sandhi
        :target: https://pypi.python.org/pypi/sandhi


.. image:: https://readthedocs.org/projects/sandhi/badge/?version=latest
        :target: https://sandhi.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status

.. image:: https://img.shields.io/pypi/pyversions/sandhi
        :target: https://pypi.python.org/pypi/sandhi
        :alt: Python Version Support

.. image:: https://img.shields.io/github/issues/hrishikeshrt/sandhi
        :target: https://github.com/hrishikeshrt/sandhi/issues
        :alt: GitHub Issues

.. image:: https://img.shields.io/github/followers/hrishikeshrt?style=social
        :target: https://github.com/hrishikeshrt
        :alt: GitHub Followers


.. image:: https://img.shields.io/twitter/follow/hrishikeshrt?style=social
        :target: https://twitter.com/hrishikeshrt
        :alt: Twitter Followers



Sanskrit Sandhi Module


* Free software: GNU General Public License v3
* Documentation: https://sandhi.readthedocs.io.


Features
========

* Form Sandhi using Ashtadhyayi Rules


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   modules
   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
